/*
 *				**** Get Info Loc ****
 *
 * This is the header file for the GetInfo Location package
 *
 * This package returns handles instead of pointers
 * when an entry is created.
 *
 * Using this approach, we can reveal to the user the exact
 * format of the data structure, but they still can't access
 * the structure directly.  They can only utilize the handle.
 */

/***************************************************
 *
 * class definitions
 *
 ***************************************************/
#define INFO_BAD_ENT		-1
#define INFO_BAD_ACCT	-1
#define INFO_BAD_BAL		-999.99
#define INFO_MAX_ENT		1000

/* GetInfo structure */
typedef struct info {
	int acct;		/* account number */
	char *fname;	/* first name */
   char *lname;	/* last name */
   float bal;		/* account balance */
} Info;

int create_info(void);	/* constructor for Info object */
void free_info(int hndl);	/* destructor for Info object */
void info_terminate(void);	/* final cleanup routine */

/* get/set routines for fields */
int get_info_acct(int hndl);
void set_info_acct(int hndl, int acct);
char *get_info_fname(int hndl);
void set_info_fname(int hndl, char *fname);
char *get_info_lname(int hndl);
void set_info_lname(int hndl, char *lname);
float get_info_bal(int hndl);
void set_info_bal(int hndl, float bal);

/* display and dump routines - used for debugging */
void display_info(int h);
void dump_info(int h, FILE *fp);

